@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS CONSTRAINT_CATALOG,
   TABLE_CONTRAINTS.OWNER AS CONSTRAINT_SCHEMA,
@@ -18,8 +24,10 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
-  REGEXP_LIKE(TABLE_CONTRAINTS.OWNER, '${schemas}')
+  REGEXP_LIKE(TABLE_CONTRAINTS.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(TABLE_CONTRAINTS.OWNER || '.' || TABLE_CONTRAINTS.TABLE_NAME, '${table-inclusion-rule}')
   AND TABLE_CONTRAINTS.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(TABLE_CONTRAINTS.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
   AND TABLE_CONTRAINTS.CONSTRAINT_TYPE IN ('C', 'U', 'P', 'R')
