@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS SYNONYM_CATALOG,
   SYNONYMS.OWNER AS SYNONYM_SCHEMA,
@@ -12,8 +18,9 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
-  REGEXP_LIKE(SYNONYMS.OWNER, '${schemas}')
+  REGEXP_LIKE(SYNONYMS.OWNER, '${schema-inclusion-rule}')
   AND SYNONYMS.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(SYNONYMS.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
 ORDER BY
