@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS PROCEDURE_CAT,
   PROCEDURES.OWNER AS PROCEDURE_SCHEM,
@@ -19,8 +25,9 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
-  REGEXP_LIKE(PROCEDURES.OWNER, '${schemas}')
+  REGEXP_LIKE(PROCEDURES.OWNER, '${schema-inclusion-rule}')
   AND PROCEDURES.OBJECT_TYPE = 'PROCEDURE'
 ORDER BY
   PROCEDURE_SCHEM,
